This folder contains schemas for externally-defined formats.

fmi-2.0-modelDescription.schema.json is the schema for modelDescription.json,
which we generate from the modelDescription.xml in a user's FMU file.
